=================
61.0 Seven Pounds
=================

The Avocado team is proud to present another release: Avocado version
60.0, AKA "Seven Pounds", is now available!

Release documentation: `Avocado 61.0
<http://avocado-framework.readthedocs.io/en/61.0/>`_

The major changes introduced on this version are listed below,
roughly categorized into major topics and intended audience:

Users/Test Writers
==================

* The ``xunit`` result plugin can now limit the amount of output
  generated by individual tests that will make into the XML based
  output file.  This is intended for situations where tests can
  generate prohibitive amounts of output that can render the file too
  large to be reused elsewhere (such as imported by Jenkins).

* SIMPLE tests can also finish with ``SKIP`` OR ``WARN`` status,
  depending on the output produced, and the Avocado test runner
  configuration. It now supports patterns that span across multiple
  lines.  For more information, refer to :ref:`test_type_simple_status`.

* Simple bytes and "unicode strings" utility functions have been added
  to :mod:`avocado.utils.astring`, and can be used by extension and
  test writers that need consistent results across Python major
  versions.

* All of core Avocado and all but one plugin (``yaml-to-mux``) now
  have all their tests enabled on Python 3.  This means that for
  virtually all use cases, the experience of Python 3 users should be
  on par to the Python 2 experience.  Please refer to
  https://trello.com/c/Q8QVmj8E/1254-bug-non-ascii-character-breaks-yaml2mux
  and
  https://trello.com/c/eFY9Vw1R/1282-python-3-functional-tests-checklist
  for the outstanding issues.

Bug Fixes
=========

* The TAP plugin was ommiting the output generated by the test from
  its own output.  Now, that functionality is back, and commented
  out output will be shown after the ``ok`` or ``not ok`` lines.

* Packaging issues which prevented proper use of RPM packages
  installations, due to the lack dependencies, were fixed.  Now, on
  both Python 2 and 3 packages, the right dependencies should be
  fulfilled.

* Replaying jobs that use the "YAML loader" is now possible.  The fix
  was the implementation of the ``fingerprint`` method, previously
  missing from the :class:`avocado.core.tree.TreeNodeEnvOnly` class.

Internal Changes
================

* The ``glib`` test loader plugin won't attempt to execute test
  references to list the glib tests, unless the test reference is an
  executable file.

* Files created after the test name, which include the ``;``
  character, will now be properly mapped to a filesystem safe ``_``;

* A number of improvements to the code quality, as a result of having
  more "warning" checks enabled on our lint check.

* A significant reduction in the default timeout used when waiting for
  hotplug operations on memory devices, as part of the utility module
  :class:`avocado.utils.memory`.

* Improved support for non-ASCII input, including the internal use of
  "unicode" string types for :func:`avocado.utils.process.run` and
  similar functions.  The command parameter given to those functions
  are now expected to be "unicode" strings.

For more information, please check out the complete
`Avocado changelog
<https://github.com/avocado-framework/avocado/compare/60.0...61.0>`_.

Release Meeting
===============

The Avocado release meetings are now open to the community via
Hangouts on Air.  The meetings are recorded and made available on the
`Avocado Test Framework YouTube channel
<https://www.youtube.com/channel/UC-RVZ_HFTbEztDM7wNY4NfA>`_.

For this release, you can watch the meeting on `this link
<https://www.youtube.com/watch?v=1N0YiM6FC48>`_.

----

| Sprint theme: https://trello.com/c/4KtpSeGT/1305-sprint-theme-farewell-2009
